function [h,codes] = LBP3x3(I, boundaryOptions)
%Compute LBP3x3
%
%INPUT
%I:                 grey-scale image
%boundaryOptions:   the way the image is repeated across borders. See
%                   CreateImageLayers
%OUTPUT
%h:                 histogram of LBP3x3 patterns (sums one)
%codes:             the transformed image

    [rows cols] = size(I);

    %Create 3x3 neighourhood
    D = CreateCircularNeighbourhood(1, 'FULL');
    
    %Create image layers
    L = CreateImageLayers(I,D,boundaryOptions);
    
    %Compute LBP codes
    codes = 2^0 * (L(:,:,2) >= L(:,:,1)) + ...
            2^1 * (L(:,:,3) >= L(:,:,1)) + ...
            2^2 * (L(:,:,4) >= L(:,:,1)) + ...
            2^3 * (L(:,:,5) >= L(:,:,1)) + ...
            2^4 * (L(:,:,6) >= L(:,:,1)) + ...
            2^5 * (L(:,:,7) >= L(:,:,1)) + ...
            2^6 * (L(:,:,8) >= L(:,:,1)) + ...
            2^7 * (L(:,:,9) >= L(:,:,1));
            
    %Compute histogram
    h = hist(codes(:),0:(2^8-1))/(rows * cols);
end