function [h,codes] = LBP3x3ri(I, boundaryOptions)
%Compute LBP3x3
%
%INPUT
%I:                 grey-scale image
%boundaryOptions:   the way the image is repeated across borders. See
%                   CreateImageLayers
%OUTPUT
%h:                 histogram of LBP3x3 patterns (sums one)
%codes:             the transformed image

    [rows cols] = size(I);
    
    [h,codes] = LBP3x3(I,boundaryOptions);

    %Create look-up table for rotation invariance
    LUT = lutRotInv('LBP81ri');

    for d = 1:numel(LUT)
        codes(codes == (d-1)) = LUT(d);
    end
            
    %Compute histogram
    h = hist(codes(:),0:max(LUT))/(rows * cols);
end