function transformedVector = TrasformFeatureVectorFFT(featureVector, nFreqs, vectorType);

%Transform a Gabor feature vector through DFT normalization
%
%INPUT:
%featureVector:         vector of Gabor features (see function 'Gabor')
%nFreqs:                no. of frequencies of the filter bank
%vectorType:            type of features in the input vector; can be:
%                           'MV' =  mean and std. dev. of the magnitude of
%                                   the transformed images
%                           'M'  =  mean of the magnitude of the transformed images   
%
%OUTPUT:
%transformedVector:     the transformed (rotation invariant) feature vector
%

    transformedVector = zeros(0,0);
    transformedSnippet = zeros(0,0);

    if vectorType == 'MV'
	
        nOrnts = size(featureVector, 2)/(2*nFreqs);
		
        meanValues = ExtractMeanValuesFromFeatureDatabase(featureVector);
        stdValues = ExtractStdValuesFromFeatureDatabase(featureVector);
    

        for i = 1:nFreqs

            %Mean values
            vectorSnippet = meanValues((1 + (i-1)*nOrnts):(i*nOrnts));
            transformedSnippet = TransformVectorSnippetFFT(vectorSnippet);
            transformedVector = horzcat(transformedVector, transformedSnippet);
		
            %Standard dev
            vectorSnippet = stdValues((1 + (i-1)*nOrnts):(i*nOrnts));
            transformedSnippet = TransformVectorSnippetFFT(vectorSnippet);
            transformedVector = horzcat(transformedVector, transformedSnippet);
		

        end
    elseif vectorType == 'M'
        for i = 1:nFreqs
		
            nOrnts = size(featureVector, 2)/(nFreqs);

            meanValues = featureVector;
		
            %Mean values
            vectorSnippet = meanValues((1 + (i-1)*nOrnts):(i*nOrnts));
            transformedSnippet = TransformVectorSnippetFFT(vectorSnippet);
            transformedVector = horzcat(transformedVector, transformedSnippet);
	
        end      
    end

end

function [meanValues] = ExtractMeanValuesFromFeatureDatabase(featureDatabase)

    count = 1;
    [rows cols] = size(featureDatabase);

    for i = 1:rows
        count = 1;
        for j = 1:2:cols
            meanValues(i,count) = featureDatabase(i,j);
            count = count + 1;
        end
    end
end


function [stdValues] = ExtractStdValuesFromFeatureDatabase(featureDatabase)

    count = 1;
    [rows cols] = size(featureDatabase);

    for i = 1:rows
        count = 1;
        for j = 2:2:cols
            stdValues(i,count) = featureDatabase(i,j);
            count = count + 1;
        end
    end
end

function reorientedSnippet = TransformVectorSnippetFFT(vectorSnippet)
    reorientedSnippet = abs(fft(vectorSnippet));
end
